<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 * The Innobase storage engine
 *
 * @package PhpMyAdmin-Engines
 */
if (! defined('PHPMYADMIN')) {
    exit;
}

/**
 *
 */
require_once './libraries/engines/innodb.lib.php';

/**
 * The Innobase storage engine
 *
 * @package PhpMyAdmin-Engines
 */
class PMA_StorageEngine_Innobase extends PMA_StorageEngine_Innodb
{
}
?>
